@@ -275,7 +275,7 @@ QString SignaturePrivate::textFromCommand(bool *ok) const
             *ok = false;
         }
         const QString wmsg = i18n("<qt>Failed to execute signature script<p><b>%1</b>:</p>"
-                                  "<p>%2</p></qt>", path, QLatin1String(proc.readAllStandardError()));
+                                  "<p>%2</p></qt>", path, QString::fromUtf8(proc.readAllStandardError()));
         KMessageBox::error(nullptr, wmsg);
         return QString();
     }
